@@ -74,7 +74,7 @@ class TerrariaPCPlayer:
 		self.name = ""
 		self.difficulty = 0
 		self.playtime = timedelta()
-		self.hair = 0
+		self.hair_style = 0
 		self.hair_dye = 0
 		self.is_accessories_hidden = Bitarray.bitarray()
 		self.is_pet_hidden = False
@@ -267,7 +267,7 @@ class TerrariaPCPlayer:
 			if version >= 138:
 				self.playtime = timedelta(microseconds=int(file.read_int64() / 10))
 
-			self.hair = file.read_int32()
+			self.hair_style = file.read_int32()
 
 			if version >= 82:
 				self.hair_dye = file.read_byte()
@@ -287,7 +287,7 @@ class TerrariaPCPlayer:
 				self.is_light_pet_hidden = bool(byte >> 1 & 1)
 
 			if version <= 17:
-				self.is_male = not (self.hair == 5 or self.hair == 6 or self.hair == 9 or self.hair == 11)
+				self.is_male = not (self.hair_style == 5 or self.hair_style == 6 or self.hair_style == 9 or self.hair_style == 11)
 				self.style = 0
 			elif version < 107:
 				self.is_male = file.read_bool()
@@ -646,7 +646,7 @@ class TerrariaPCPlayer:
 					raise ValueError("playtime may not be above -10675200,21:11:54.522278")
 				file.write_int64(int(self.playtime.total_seconds() * 10000000))
 
-			file.write_int32(self.hair)
+			file.write_int32(self.hair_style)
 
 			if version >= 82:
 				file.write_byte(self.hair_dye)
@@ -958,7 +958,7 @@ class TerrariaPCPlayer:
 	name = ""
 	difficulty = 0
 	playtime = timedelta()
-	hair = 0
+	hair_style = 0
 	hair_dye = 0
 	is_accessories_hidden = Bitarray.bitarray()
 	is_pet_hidden = False
